<?php

// Login credentials for the site administrator.
// You can modify these to suit your installation.
// Be sure to only change the text within the double quotes.
// The double quotes themselves should remain in place.

// Username.
$site_admin_username = "adminusername";
// Password.
$site_admin_password = "adminpassword";

// Whether this is an open installation.
// false: It is the standard password protected installation.
// true: It is an open installation.

// Open installation.
$open_installation = false;

?>
